Index: include/v8-profiler.h |
diff --git a/include/v8-profiler.h b/include/v8-profiler.h |
index 675a229854ef086f617fae15823f2af8a6da4725..b01b8e7bf659f21babcd7f3195510985947c4672 100644 |
--- a/include/v8-profiler.h |
+++ b/include/v8-profiler.h |
@@ -245,14 +245,15 @@ class V8EXPORT HeapGraphPath { |
class V8EXPORT HeapGraphNode { |
public: |
enum Type { |
- kHidden = 0, // Hidden node, may be filtered when shown to user. |
- kArray = 1, // An array of elements. |
- kString = 2, // A string. |
- kObject = 3, // A JS object (except for arrays and strings). |
- kCode = 4, // Compiled code. |
- kClosure = 5, // Function closure. |
- kRegExp = 6, // RegExp. |
- kHeapNumber = 7 // Number stored in the heap. |
+ kHidden = 0, // Hidden node, may be filtered when shown to user. |
+ kArray = 1, // An array of elements. |
+ kString = 2, // A string. |
+ kObject = 3, // A JS object (except for arrays and strings). |
+ kCode = 4, // Compiled code. |
+ kClosure = 5, // Function closure. |
+ kRegExp = 6, // RegExp. |
+ kHeapNumber = 7, // Number stored in the heap. |
+ kNative = 8 // Native object (not from V8 heap). |
}; |
/** Returns node type (see HeapGraphNode::Type). */ |
@@ -397,6 +398,13 @@ class V8EXPORT HeapSnapshot { |
*/ |
class V8EXPORT HeapProfiler { |
public: |
+ /** |
+ * Callback function invoked for obtaining RetainedObjectInfo for |
+ * the given JavaScript wrapper object. |
Vitaly Repeshko
2011/03/09 14:15:49
We should document that its prohibited to enter V8
mnaganov (inactive)
2011/03/09 15:26:32
Done.
|
+ */ |
+ typedef RetainedObjectInfo* (*WrapperInfoCallback) |
+ (uint16_t class_id, Handle<Value> wrapper); |
+ |
/** Returns the number of snapshots taken. */ |
static int GetSnapshotsCount(); |
@@ -414,6 +422,11 @@ class V8EXPORT HeapProfiler { |
Handle<String> title, |
HeapSnapshot::Type type = HeapSnapshot::kFull, |
ActivityControl* control = NULL); |
+ |
+ /** Binds a callback to embedder's class ID. */ |
Vitaly Repeshko
2011/03/09 14:15:49
Move the "no class" constant here and document tha
mnaganov (inactive)
2011/03/09 15:26:32
Done.
|
+ static void DefineWrapperClass( |
+ uint16_t class_id, |
+ WrapperInfoCallback callback); |
}; |